@@ -2,6 +2,7 @@ import os
 from pathlib import Path
 from functools import cached_property
 
+
 class UniqueWorker:
     def __init__(self, path):
         self.path = Path(path)
@@ -9,8 +10,8 @@ class UniqueWorker:
         self._set_id()
 
     def _set_id(self):
-        if self.path.exists():
-            self.path.parents[0].mkdir(parents=True, exist_ok=True)
+        self.path.parents[0].mkdir(parents=True, exist_ok=True)
+        self.path.touch(exist_ok=True)
 
         with open(self.path, "w") as f:
             f.write(self.id)
